@@ -108,6 +108,11 @@
         <source>Create new folder</source>
         <translation type="unfinished">Crear nueva carpeta</translation>
     </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Sort</source>
+        <translation type="unfinished">Ordenar</translation>
+    </message>
 </context>
 <context>
     <name>Share</name>
@@ -343,6 +348,11 @@
         <source>Home folder</source>
         <translation type="unfinished">Carpeta de inicio</translation>
     </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Icons Style</source>
+        <translation type="unfinished">Estilo de íconos</translation>
+    </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Enable root access (restart needed)</source>
@@ -353,6 +363,11 @@
         <source>Show hidden files and folders</source>
         <translation type="unfinished">Mostrar archivos y carpetas ocultos</translation>
     </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Show thumbnails for images</source>
+        <translation type="unfinished">Mostrar miniaturas para imágenes</translation>
+    </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Delete items from clipboard on Paste</source>
@@ -466,4 +481,43 @@
         <translation type="unfinished">No</translation>
     </message>
 </context>
+<context>
+    <name>Sort</name>
+    <message>
+        <location filename="../sort.cpp" line="10"/>
+        <source>Sort</source>
+        <translation type="unfinished">Ordenar</translation>
+    </message>
+    <message>
+        <location filename="../sort.cpp" line="10"/>
+        <source>Name (A-Z)</source>
+        <translation type="unfinished">Nombre (A-Z)</translation>
+    </message>
+    <message>
+        <location filename="../sort.cpp" line="10"/>
+        <source>Name (Z-A)</source>
+        <translation type="unfinished">Nombre (Z-A)</translation>
+    </message>
+    <message>
+        <location filename="../sort.cpp" line="10"/>
+        <source>Date (olders first)</source>
+        <translation type="unfinished">Fecha (viejos primero)</translation>
+    </message>
+    <message>
+        <location filename="../sort.cpp" line="10"/>
+        <source>Date (recents first)</source>
+        <translation type="unfinished">Fecha (recientes primero)</translation>
+    </message>
+    <message>
+        <location filename="../sort.cpp" line="10"/>
+        <source>Size (smallers first)</source>
+        <translation type="unfinished">Tamaño (pequeños primero)</translation>
+    </message>
+    <message>
+        <location filename="../sort.cpp" line="10"/>
+        <source>Size (biggers first)</source>
+        <translation type="unfinished">Tamaño (grandes primero)</translation>
+    </message>
+</context>
+
 </TS>
